@@ -14,6 +14,7 @@
 #include <gtk/gtk.h>
 #include <cairo.h>
 
+#include "task-manager.h"
 #include "process-monitor.h"
 
 
@@ -63,7 +64,7 @@ xtm_process_monitor_class_init (XtmProcessMonitorClass *klass)
 	widget_class->expose_event = xtm_process_monitor_expose;
 #endif
 	g_object_class_install_property (class, PROP_STEP_SIZE,
-		g_param_spec_float ("step-size", "StepSize", "Step size", 0.1, G_MAXFLOAT, 1, G_PARAM_CONSTRUCT|G_PARAM_READWRITE));
+		g_param_spec_float ("step-size", "StepSize", "Step size", 0.1f, G_MAXFLOAT, 1, G_PARAM_CONSTRUCT|G_PARAM_READWRITE));
 	g_object_class_install_property (class, PROP_TYPE,
 		g_param_spec_int ("type", "Type", "Type of graph to render", 0, G_MAXINT, 0, G_PARAM_READWRITE));
 }
@@ -121,7 +122,7 @@ xtm_process_monitor_draw (GtkWidget *widget, cairo_t *cr)
 	XtmProcessMonitor *monitor = XTM_PROCESS_MONITOR (widget);
 	guint minimum_history_length;
 
-	minimum_history_length = gtk_widget_get_allocated_width(widget) / monitor->step_size;
+	minimum_history_length = (guint)(gtk_widget_get_allocated_width(widget) / monitor->step_size);
 	if (monitor->history->len < minimum_history_length)
 		g_array_set_size (monitor->history, minimum_history_length + 1);
 
@@ -130,13 +131,13 @@ xtm_process_monitor_draw (GtkWidget *widget, cairo_t *cr)
 }
 #else
 static gboolean
-xtm_process_monitor_expose (GtkWidget *widget, GdkEventExpose *event)
+xtm_process_monitor_expose (GtkWidget *widget, GdkEventExpose *event __unused)
 {
 	XtmProcessMonitor *monitor = XTM_PROCESS_MONITOR (widget);
 	guint minimum_history_length;
 	cairo_t *cr;
 
-	minimum_history_length = widget->allocation.width / monitor->step_size;
+	minimum_history_length = (guint)(widget->allocation.width / monitor->step_size);
 	if (monitor->history->len < minimum_history_length)
 		g_array_set_size (monitor->history, minimum_history_length + 1);
 
@@ -153,7 +154,7 @@ xtm_process_monitor_graph_surface_create (XtmProcessMonitor *monitor, gint width
 	cairo_t *cr;
 	cairo_surface_t *graph_surface;
 	gfloat *peak;
-	gfloat step_size;
+	gdouble step_size;
 	gint i;
 
 	if (monitor->history->len <= 1)
@@ -161,7 +162,7 @@ xtm_process_monitor_graph_surface_create (XtmProcessMonitor *monitor, gint width
 		g_warning ("Cannot paint graph with n_peak <= 1");
 		return NULL;
 	}
-	step_size = monitor->step_size;
+	step_size = (gdouble)monitor->step_size;
 
 	graph_surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, width, height);
 	cr = cairo_create (graph_surface);
@@ -180,7 +181,7 @@ xtm_process_monitor_graph_surface_create (XtmProcessMonitor *monitor, gint width
 	{
 		peak = &g_array_index (monitor->history, gfloat, i);
 		cairo_translate (cr, -step_size, 0);
-		cairo_line_to (cr, width, (1.0 - *peak) * height);
+		cairo_line_to (cr, width, (1.0 - ((gdouble)(*peak))) * height);
 	}
 	cairo_line_to (cr, width, height);
 	cairo_fill (cr);
@@ -201,7 +202,7 @@ xtm_process_monitor_graph_surface_create (XtmProcessMonitor *monitor, gint width
 	{
 		peak = &g_array_index (monitor->history, gfloat, i);
 		cairo_translate (cr, -step_size, 0);
-		cairo_line_to (cr, width, (1.0 - *peak) * height);
+		cairo_line_to (cr, width, (1.0 - ((gdouble)(*peak))) * height);
 	}
 	cairo_stroke (cr);
 
@@ -267,7 +268,7 @@ void
 xtm_process_monitor_add_peak (XtmProcessMonitor *monitor, gfloat peak)
 {
 	g_return_if_fail (XTM_IS_PROCESS_MONITOR (monitor));
-	g_return_if_fail (peak >= 0.0 && peak <= 1.0);
+	g_return_if_fail (peak >= 0.0f && peak <= 1.0f);
 
 	g_array_prepend_val (monitor->history, peak);
 	if (monitor->history->len > 1)
