@@ -11,6 +11,7 @@
 #include <config.h>
 #endif
 
+#include <unistd.h>
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <glib/gprintf.h>
@@ -90,14 +91,9 @@ xtm_process_tree_view_init (XtmProcessTreeView *treeview)
 	gboolean tree;
 
 	treeview->settings = xtm_settings_get_default ();
+	treeview->owner_uid = getuid ();
 	g_signal_connect (treeview->settings, "notify", G_CALLBACK (settings_changed), treeview);
-
-	{
-		gchar *uid_name;
-		get_owner_uid (&treeview->owner_uid, &uid_name);
-		g_free (uid_name);
-		g_object_get (treeview->settings, "show-all-processes", &treeview->show_all_processes_cached, "process-tree", &tree, NULL);
-	}
+	g_object_get (treeview->settings, "show-all-processes", &treeview->show_all_processes_cached, "process-tree", &tree, NULL);
 
 	/* Create tree view model */
 #ifdef HAVE_WNCK
@@ -212,11 +208,12 @@ xtm_process_tree_view_init (XtmProcessTreeView *treeview)
 
 	/* Set initial sort column */
 	{
-		guint sort_column_id;
+		guint sort_column_idu;
+		gint sort_column_id;
 		GtkSortType sort_type;
 
-		g_object_get (treeview->settings, "sort-column-id", &sort_column_id, "sort-type", &sort_type, NULL);
-		treeview->sort_column = gtk_tree_view_get_column (GTK_TREE_VIEW (treeview), treeview->columns_positions[sort_column_id]);
+		g_object_get (treeview->settings, "sort-column-id", &sort_column_idu, "sort-type", &sort_type, NULL);
+		treeview->sort_column = gtk_tree_view_get_column (GTK_TREE_VIEW (treeview), treeview->columns_positions[sort_column_idu]);
 		gtk_tree_view_column_set_sort_indicator (treeview->sort_column, TRUE);
 		gtk_tree_view_column_set_sort_order (treeview->sort_column, sort_type);
 		sort_column_id = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (treeview->sort_column), "sort-column-id"));
@@ -292,7 +289,7 @@ columns_changed (XtmProcessTreeView *treeview)
 	GList *columns, *l;
 	GtkTreeViewColumn *column;
 	gint column_id;
-	gint i;
+	gushort i;
 
 	columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (treeview));
 	if (g_list_length (columns) < N_COLUMNS)
@@ -315,7 +312,7 @@ columns_changed (XtmProcessTreeView *treeview)
 static void
 read_columns_positions (XtmProcessTreeView *treeview)
 {
-	gint i;
+	gushort i;
 	gchar *columns_positions;
 	gchar **columns_positions_split;
 
@@ -330,7 +327,7 @@ read_columns_positions (XtmProcessTreeView *treeview)
 	{
 		columns_positions_split = g_strsplit (columns_positions, ";", N_COLUMNS + 1);
 		for (i = 0; i < N_COLUMNS && columns_positions_split[i] != NULL; i++)
-			treeview->columns_positions[i] = (gint)g_ascii_strtoll (columns_positions_split[i], NULL, 10);
+			treeview->columns_positions[i] = (gushort)g_ascii_strtoll (columns_positions_split[i], NULL, 10);
 		g_strfreev (columns_positions_split);
 		g_free (columns_positions);
 	}
@@ -340,12 +337,12 @@ static void
 save_columns_positions (XtmProcessTreeView *treeview)
 {
 	gint i;
-	gint offset = 0;
+	gulong offset = 0;
 #define COLUMNS_POSITIONS_STRLEN (N_COLUMNS * 4 + 1)
 	gchar columns_positions[COLUMNS_POSITIONS_STRLEN] = { 0 };
 
 	for (i = 0; i < N_COLUMNS; i++)
-		offset += g_snprintf (&columns_positions[offset], COLUMNS_POSITIONS_STRLEN - offset, "%d;", treeview->columns_positions[i]);
+		offset += (gulong)g_snprintf (&columns_positions[offset], (sizeof(columns_positions) - offset), "%d;", treeview->columns_positions[i]);
 
 	g_object_set (treeview->settings, "columns-positions", columns_positions, NULL);
 }
@@ -356,7 +353,7 @@ cb_send_signal (GtkMenuItem *mi, gpointer user_data)
 	XtmSettings *settings;
 	gboolean prompt_terminate_task;
 	GtkWidget *dialog;
-	guint pid = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (mi), "pid"));
+	GPid pid = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (mi), "pid"));
 	gint xtm_signal = GPOINTER_TO_INT (user_data);
 
 	settings = xtm_settings_get_default ();
@@ -397,6 +394,8 @@ cb_send_signal (GtkMenuItem *mi, gpointer user_data)
 		GtkTreeSelection *selection;
 		GtkWidget *treeview;
 		treeview = g_object_get_data (G_OBJECT (mi), "treeview");
+		if (NULL == treeview)
+			return;
 		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
 		gtk_tree_selection_unselect_all (selection);
 	}
@@ -405,7 +404,7 @@ cb_send_signal (GtkMenuItem *mi, gpointer user_data)
 static void
 cb_set_priority (GtkMenuItem *mi, gpointer user_data)
 {
-	guint pid = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (mi), "pid"));
+	GPid pid = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (mi), "pid"));
 	gint priority = GPOINTER_TO_INT (user_data);
 
 	if (!set_priority_to_pid (pid, priority))
@@ -422,7 +421,7 @@ cb_set_priority (GtkMenuItem *mi, gpointer user_data)
 }
 
 static GtkWidget *
-build_context_menu (XtmProcessTreeView *treeview, guint pid)
+build_context_menu (XtmProcessTreeView *treeview, GPid pid)
 {
 	GtkWidget *menu, *menu_priority, *mi;
 
@@ -431,53 +430,53 @@ build_context_menu (XtmProcessTreeView *treeview, guint pid)
 	if (!pid_is_sleeping (pid))
 	{
 		mi = gtk_menu_item_new_with_label (_("Stop"));
-		g_object_set_data (G_OBJECT (mi), "pid", GUINT_TO_POINTER (pid));
+		g_object_set_data (G_OBJECT (mi), "pid", GINT_TO_POINTER (pid));
 		gtk_container_add (GTK_CONTAINER (menu), mi);
 		g_signal_connect (mi, "activate", G_CALLBACK (cb_send_signal), GINT_TO_POINTER (XTM_SIGNAL_STOP));
 	}
 	else
 	{
 		mi = gtk_menu_item_new_with_label (_("Continue"));
-		g_object_set_data (G_OBJECT (mi), "pid", GUINT_TO_POINTER (pid));
+		g_object_set_data (G_OBJECT (mi), "pid", GINT_TO_POINTER (pid));
 		gtk_container_add (GTK_CONTAINER (menu), mi);
 		g_signal_connect (mi, "activate", G_CALLBACK (cb_send_signal), GINT_TO_POINTER (XTM_SIGNAL_CONTINUE));
 	}
 
 	mi = gtk_menu_item_new_with_label (_("Terminate"));
-	g_object_set_data (G_OBJECT (mi), "pid", GUINT_TO_POINTER (pid));
+	g_object_set_data (G_OBJECT (mi), "pid", GINT_TO_POINTER (pid));
 	g_object_set_data (G_OBJECT (mi), "treeview", treeview);
 	gtk_container_add (GTK_CONTAINER (menu), mi);
 	g_signal_connect (mi, "activate", G_CALLBACK (cb_send_signal), GINT_TO_POINTER (XTM_SIGNAL_TERMINATE));
 
 	mi = gtk_menu_item_new_with_label (_("Kill"));
-	g_object_set_data (G_OBJECT (mi), "pid", GUINT_TO_POINTER (pid));
+	g_object_set_data (G_OBJECT (mi), "pid", GINT_TO_POINTER (pid));
 	gtk_container_add (GTK_CONTAINER (menu), mi);
 	g_signal_connect (mi, "activate", G_CALLBACK (cb_send_signal), GINT_TO_POINTER (XTM_SIGNAL_KILL));
 
 	menu_priority = gtk_menu_new ();
 
 	mi = gtk_menu_item_new_with_label (_("Very low"));
-	g_object_set_data (G_OBJECT (mi), "pid", GUINT_TO_POINTER (pid));
+	g_object_set_data (G_OBJECT (mi), "pid", GINT_TO_POINTER (pid));
 	gtk_container_add (GTK_CONTAINER (menu_priority), mi);
 	g_signal_connect (mi, "activate", G_CALLBACK (cb_set_priority), GINT_TO_POINTER (XTM_PRIORITY_VERY_LOW));
 
 	mi = gtk_menu_item_new_with_label (_("Low"));
-	g_object_set_data (G_OBJECT (mi), "pid", GUINT_TO_POINTER (pid));
+	g_object_set_data (G_OBJECT (mi), "pid", GINT_TO_POINTER (pid));
 	gtk_container_add (GTK_CONTAINER (menu_priority), mi);
 	g_signal_connect (mi, "activate", G_CALLBACK (cb_set_priority), GINT_TO_POINTER (XTM_PRIORITY_LOW));
 
 	mi = gtk_menu_item_new_with_label (_("Normal"));
-	g_object_set_data (G_OBJECT (mi), "pid", GUINT_TO_POINTER (pid));
+	g_object_set_data (G_OBJECT (mi), "pid", GINT_TO_POINTER (pid));
 	gtk_container_add (GTK_CONTAINER (menu_priority), mi);
 	g_signal_connect (mi, "activate", G_CALLBACK (cb_set_priority), GINT_TO_POINTER (XTM_PRIORITY_NORMAL));
 
 	mi = gtk_menu_item_new_with_label (_("High"));
-	g_object_set_data (G_OBJECT (mi), "pid", GUINT_TO_POINTER (pid));
+	g_object_set_data (G_OBJECT (mi), "pid", GINT_TO_POINTER (pid));
 	gtk_container_add (GTK_CONTAINER (menu_priority), mi);
 	g_signal_connect (mi, "activate", G_CALLBACK (cb_set_priority), GINT_TO_POINTER (XTM_PRIORITY_HIGH));
 
 	mi = gtk_menu_item_new_with_label (_("Very high"));
-	g_object_set_data (G_OBJECT (mi), "pid", GUINT_TO_POINTER (pid));
+	g_object_set_data (G_OBJECT (mi), "pid", GINT_TO_POINTER (pid));
 	gtk_container_add (GTK_CONTAINER (menu_priority), mi);
 	g_signal_connect (mi, "activate", G_CALLBACK (cb_set_priority), GINT_TO_POINTER (XTM_PRIORITY_VERY_HIGH));
 
@@ -491,7 +490,7 @@ build_context_menu (XtmProcessTreeView *treeview, guint pid)
 }
 
 static void
-position_menu (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, XtmProcessTreeView *treeview)
+position_menu (GtkMenu *menu __unused, gint *x, gint *y, gboolean *push_in, XtmProcessTreeView *treeview)
 {
 	gdk_window_get_origin (gtk_tree_view_get_bin_window (GTK_TREE_VIEW (treeview)), x, y);
 	*x += 5;
@@ -500,7 +499,7 @@ position_menu (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, XtmProcessTre
 }
 
 static void
-popup_menu (XtmProcessTreeView *treeview, guint pid, guint activate_time, gboolean at_pointer_position)
+popup_menu (XtmProcessTreeView *treeview, GPid pid, guint activate_time, gboolean at_pointer_position)
 {
 	static GtkWidget *menu = NULL;
 	GtkMenuPositionFunc position_func = NULL;
@@ -518,35 +517,28 @@ popup_menu (XtmProcessTreeView *treeview, guint pid, guint activate_time, gboole
 static gboolean
 treeview_clicked (XtmProcessTreeView *treeview, GdkEventButton *event)
 {
-	guint pid;
+	GtkTreeModel *model;
+	GtkTreeSelection *selection;
+	GtkTreePath *path;
+	GtkTreeIter iter;
+	gboolean tree;
+	GPid pid;
 
 	if (event->button != 3)
 		return FALSE;
 
-	{
-		GtkTreeModel *model;
-		GtkTreeSelection *selection;
-		GtkTreePath *path;
-		GtkTreeIter iter;
-		gboolean tree;
+	g_object_get (treeview->settings, "process-tree", &tree, NULL);
+	model = GTK_TREE_MODEL (tree ? treeview->model_tree : treeview->model_filter);
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
+	gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (treeview), (gint)event->x, (gint)event->y, &path, NULL, NULL, NULL);
+	if (path == NULL)
+		return FALSE;
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_model_get (model, &iter, XTM_PTV_COLUMN_PID, &pid, -1);
+	gtk_tree_selection_select_path (selection, path);
+	gtk_tree_path_free (path);
 
-		g_object_get (treeview->settings, "process-tree", &tree, NULL);
-		model = GTK_TREE_MODEL (tree ? treeview->model_tree : treeview->model_filter);
-		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
-		gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (treeview), (gint)event->x, (gint)event->y, &path, NULL, NULL, NULL);
-
-		if (path == NULL)
-			return FALSE;
-
-		gtk_tree_model_get_iter (model, &iter, path);
-		gtk_tree_model_get (model, &iter, XTM_PTV_COLUMN_PID, &pid, -1);
-		gtk_tree_selection_select_path (selection, path);
-		gtk_tree_path_free (path);
-
-#if DEBUG
-		g_debug ("Found iter with pid %d", pid);
-#endif
-	}
+	G_DEBUG_FMT ("Found iter with pid %d", pid);
 
 	popup_menu (treeview, pid, event->time, TRUE);
 
@@ -556,7 +548,7 @@ treeview_clicked (XtmProcessTreeView *treeview, GdkEventButton *event)
 static gboolean
 treeview_key_pressed (XtmProcessTreeView *treeview, GdkEventKey *event)
 {
-	guint pid;
+	GPid pid;
 
 	GtkTreeModel *model;
 	GtkTreeSelection *selection;
@@ -582,7 +574,7 @@ treeview_key_pressed (XtmProcessTreeView *treeview, GdkEventKey *event)
 		/* Fake menuitem for the cb_send_signal callback */
 		GtkWidget *mi;
 		mi = gtk_menu_item_new_with_label (_("Stop"));
-		g_object_set_data (G_OBJECT (mi), "pid", GUINT_TO_POINTER (pid));
+		g_object_set_data (G_OBJECT (mi), "pid", GINT_TO_POINTER (pid));
 		if ((event->state & modifiers) == GDK_SHIFT_MASK)
 			cb_send_signal (GTK_MENU_ITEM (mi), GINT_TO_POINTER (XTM_SIGNAL_KILL));
 		else
@@ -601,9 +593,7 @@ column_clicked (GtkTreeViewColumn *column, XtmProcessTreeView *treeview)
 	GtkSortType sort_type;
 
 	gtk_tree_sortable_get_sort_column_id (GTK_TREE_SORTABLE (treeview->model), &sort_column_id, &sort_type);
-#if DEBUG
-	g_debug ("Last sort column %d; sort type: %d", sort_column_id, sort_type);
-#endif
+	G_DEBUG_FMT ("Last sort column %d; sort type: %d", sort_column_id, sort_type);
 
 	if (treeview->sort_column != column)
 	{
@@ -617,9 +607,7 @@ column_clicked (GtkTreeViewColumn *column, XtmProcessTreeView *treeview)
 		sort_type = (sort_type == GTK_SORT_ASCENDING) ? GTK_SORT_DESCENDING : GTK_SORT_ASCENDING;
 	}
 
-#if DEBUG
-	g_debug ("New sort column %d; sort type: %d", sort_column_id, sort_type);
-#endif
+	G_DEBUG_FMT ("New sort column %d; sort type: %d", sort_column_id, sort_type);
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (treeview->model), sort_column_id, sort_type);
 	gtk_tree_view_column_set_sort_order (column, sort_type);
 
@@ -668,7 +656,7 @@ visible_func (GtkTreeModel *model, GtkTreeIter *iter, XtmProcessTreeView *treevi
 }
 
 static gboolean
-search_func (GtkTreeModel *model, gint column, const gchar *key, GtkTreeIter *iter, gpointer user_data)
+search_func (GtkTreeModel *model, gint column __unused, const gchar *key, GtkTreeIter *iter, gpointer user_data __unused)
 {
 	gchar *cmdline, *cmdline_lower;
 	gchar *key_lower;
@@ -738,14 +726,14 @@ settings_changed (GObject *object, GParamSpec *pspec, XtmProcessTreeView *treevi
 		}
 		else
 		{
-			g_signal_handlers_disconnect_by_func (treeview->model_tree, G_CALLBACK (expand_row), treeview);
+			g_signal_handlers_disconnect_by_func (treeview->model_tree, (gpointer)G_CALLBACK (expand_row), treeview);
 		}
 	}
 }
 
 
 static void
-expand_row (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, XtmProcessTreeView *treeview)
+expand_row (GtkTreeModel *model __unused, GtkTreePath *path, GtkTreeIter *iter __unused, XtmProcessTreeView *treeview)
 {
 	gtk_tree_view_expand_row (GTK_TREE_VIEW (treeview), path, FALSE);
 }
@@ -772,13 +760,13 @@ xtm_process_tree_view_get_model (XtmProcessTreeView *treeview)
 }
 
 void
-xtm_process_tree_view_highlight_pid (XtmProcessTreeView *treeview, guint pid) {
+xtm_process_tree_view_highlight_pid (XtmProcessTreeView *treeview, GPid pid) {
 	GtkTreeModel	*model;
 	GtkTreePath		*path;
 	GtkTreeIter 	 iter;
 	gboolean     	 valid;
 	gboolean			 tree;
-	guint					 pid_iter;
+	GPid		pid_iter;
 	GtkTreeIter	child_iter;
 	gboolean validParent;
 
