@@ -29,6 +29,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include "settings.h"
+#include "task-manager.h"
 #include "process-window.h"
 #if GTK_CHECK_VERSION(3, 0, 0)
 #include "process-window-gtk3_ui.h"
@@ -81,8 +82,8 @@ static void	show_about_dialog				(XtmProcessWindow *window);
 static void
 filter_entry_icon_pressed_cb (GtkEntry *entry,
                               gint position,
-                              GdkEventButton *event,
-                              gpointer data)
+                              GdkEventButton *event __unused,
+                              gpointer data __unused)
 {
 	if (position == GTK_ENTRY_ICON_SECONDARY) {
 		gtk_entry_set_text (entry, "");
@@ -90,7 +91,7 @@ filter_entry_icon_pressed_cb (GtkEntry *entry,
 	}
 }
 
-Window
+static Window
 Select_Window (Display *dpy, int screen)
 {
 	int status;
@@ -137,22 +138,18 @@ Select_Window (Display *dpy, int screen)
 }
 
 static void
-xwininfo_clicked_cb (GtkButton *button, gpointer user_data) {
+xwininfo_clicked_cb (GtkButton *button __unused, gpointer user_data) {
 	XtmProcessWindow *window = (XtmProcessWindow *) user_data;
 	Window selected_window;
-	Display *dpy = NULL;
-	XID id = None;
-
+	Display *dpy;
 	Atom atom_NET_WM_PID;
-	long _nitems;
-	int size;
+	unsigned long _nitems;
 	Atom actual_type;
 	int actual_format;
 	unsigned char *prop;
 	int status;
 	unsigned long bytes_after;
-
-	guint pid = 0;
+	GPid pid = 0;
 
 	dpy = XOpenDisplay (NULL);
 	selected_window = Select_Window (dpy, 0);
@@ -174,7 +171,7 @@ xwininfo_clicked_cb (GtkButton *button, gpointer user_data) {
                                     _("XGetWindowProperty failed"), _("XGetWindowProperty failed!"));
 	} else {
 		if (_nitems > 0) {
-			pid = (guint) *((unsigned long*)prop);
+			memcpy(&pid, prop, sizeof(pid));
 			xtm_process_tree_view_highlight_pid(XTM_PROCESS_TREE_VIEW (window->treeview), pid);
 		} else {
 			XTM_SHOW_MESSAGE(GTK_MESSAGE_INFO,
@@ -274,14 +271,14 @@ xtm_process_window_init (XtmProcessWindow *window)
 
 		toolitem = GTK_WIDGET (gtk_builder_get_object (window->builder, "graph-cpu"));
 		window->cpu_monitor = xtm_process_monitor_new ();
-		xtm_process_monitor_set_step_size (XTM_PROCESS_MONITOR (window->cpu_monitor), refresh_rate / 1000.0);
+		xtm_process_monitor_set_step_size (XTM_PROCESS_MONITOR (window->cpu_monitor), refresh_rate / 1000.0f);
 		xtm_process_monitor_set_type (XTM_PROCESS_MONITOR (window->cpu_monitor), 0);
 		gtk_widget_show (window->cpu_monitor);
 		gtk_container_add (GTK_CONTAINER (toolitem), window->cpu_monitor);
 
 		toolitem = GTK_WIDGET (gtk_builder_get_object (window->builder, "graph-mem"));
 		window->mem_monitor = xtm_process_monitor_new ();
-		xtm_process_monitor_set_step_size (XTM_PROCESS_MONITOR (window->mem_monitor), refresh_rate / 1000.0);
+		xtm_process_monitor_set_step_size (XTM_PROCESS_MONITOR (window->mem_monitor), refresh_rate / 1000.0f);
 		xtm_process_monitor_set_type (XTM_PROCESS_MONITOR (window->mem_monitor), 1);
 		gtk_widget_show (window->mem_monitor);
 		gtk_container_add (GTK_CONTAINER (toolitem), window->mem_monitor);
@@ -395,11 +392,11 @@ xtm_process_window_key_pressed (XtmProcessWindow *window, GdkEventKey *event)
 	gboolean ret = FALSE;
 
 	if (event->keyval == GDK_KEY_Escape ||
-		event->keyval == GDK_KEY_q && (event->state & GDK_CONTROL_MASK)) {
+		(event->keyval == GDK_KEY_q && (event->state & GDK_CONTROL_MASK))) {
 		emit_delete_event_signal (window, (GdkEvent*) event);
 		ret = TRUE;
 	}
-	else if (event->keyval == GDK_KEY_f && event->state & GDK_CONTROL_MASK) {
+	else if (event->keyval == GDK_KEY_f && (event->state & GDK_CONTROL_MASK)) {
 		gtk_widget_grab_focus (GTK_WIDGET(window->filter_entry));
 		ret = TRUE;
 	}
@@ -557,7 +554,7 @@ xtm_process_window_get_model (XtmProcessWindow *window)
 }
 
 void
-xtm_process_window_set_system_info (XtmProcessWindow *window, guint num_processes, gfloat cpu, gfloat memory, gchar* memory_str, gfloat swap, gchar* swap_str)
+xtm_process_window_set_system_info (XtmProcessWindow *window, guint num_processes, gfloat cpu, gfloat memory, gchar* memory_str, gfloat swap __unused, gchar* swap_str)
 {
 	gchar text[100];
 	gchar value[4];
@@ -567,13 +564,13 @@ xtm_process_window_set_system_info (XtmProcessWindow *window, guint num_processe
 
 	g_object_set (window->statusbar, "num-processes", num_processes, "cpu", cpu, "memory", memory_str, "swap", swap_str, NULL);
 
-	xtm_process_monitor_add_peak (XTM_PROCESS_MONITOR (window->cpu_monitor), cpu / 100.0);
-	g_snprintf (value, 4, "%.0f", cpu);
-	g_snprintf (text, 100, _("CPU: %s%%"), value);
+	xtm_process_monitor_add_peak (XTM_PROCESS_MONITOR (window->cpu_monitor), cpu / 100.0f);
+	g_snprintf (value, sizeof(value), "%.0f", cpu);
+	g_snprintf (text, sizeof(text), _("CPU: %s%%"), value);
 	gtk_widget_set_tooltip_text (window->cpu_monitor, text);
 
-	xtm_process_monitor_add_peak (XTM_PROCESS_MONITOR (window->mem_monitor), memory / 100.0);
-	g_snprintf (text, 100, _("Memory: %s"), memory_str);
+	xtm_process_monitor_add_peak (XTM_PROCESS_MONITOR (window->mem_monitor), memory / 100.0f);
+	g_snprintf (text, sizeof(text), _("Memory: %s"), memory_str);
 	gtk_widget_set_tooltip_text (window->mem_monitor, text);
 }
 
