@@ -11,7 +11,6 @@
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <pwd.h>
 #include <unistd.h>
 #include <string.h>
 
@@ -40,7 +39,7 @@ get_memory_usage (guint64 *memory_total, guint64 *memory_free, guint64 *memory_c
 	*swap_total = 0;
 	*swap_free = 0;
 
-	while (found < 6 && fgets (buffer, 1024, file) != NULL)
+	while (found < 6 && fgets (buffer, sizeof(buffer), file) != NULL)
 	{
 		found += sscanf (buffer, "MemTotal:\t%llu kB", (unsigned long long*)memory_total);
 		found += sscanf (buffer, "MemFree:\t%llu kB", (unsigned long long*)memory_free);
@@ -71,14 +70,19 @@ get_cpu_usage (gushort *cpu_count, gfloat *cpu_user, gfloat *cpu_system)
 	static gulong jiffies_user_old = 0, jiffies_system_old = 0, jiffies_total_old = 0;
 	gulong user = 0, user_nice = 0, system = 0, idle = 0;
 
-	if ((file = fopen (filename, "r")) == NULL || fgets (buffer, 1024, file) == NULL)
+	if ((file = fopen (filename, "r")) == NULL)
 		return FALSE;
+	if (fgets (buffer, sizeof(buffer), file) == NULL)
+	{
+		fclose (file);
+		return FALSE;
+	}
 
 	sscanf (buffer, "cpu\t%lu %lu %lu %lu", &user, &user_nice, &system, &idle);
 
 	if (_cpu_count == 0)
 	{
-		while (fgets (buffer, 1024, file) != NULL)
+		while (fgets (buffer, sizeof(buffer), file) != NULL)
 		{
 			if (buffer[0] != 'c' && buffer[1] != 'p' && buffer[2] != 'u')
 				break;
@@ -98,12 +102,12 @@ get_cpu_usage (gushort *cpu_count, gfloat *cpu_user, gfloat *cpu_system)
 	jiffies_system = system;
 	jiffies_total = jiffies_user + jiffies_system + idle;
 
-	*cpu_user = *cpu_system = 0.0;
+	*cpu_user = *cpu_system = 0.0f;
 	if (jiffies_total > jiffies_total_old)
 	{
 		jiffies_total_delta = jiffies_total - jiffies_total_old;
-		*cpu_user = (jiffies_user - jiffies_user_old) * 100 / (gdouble)(jiffies_total_delta);
-		*cpu_system = (jiffies_system - jiffies_system_old) * 100 / (gdouble)(jiffies_total_delta);
+		*cpu_user = (((jiffies_user - jiffies_user_old) * 100.0f) / (float)jiffies_total_delta);
+		*cpu_system = (((jiffies_system - jiffies_system_old) * 100.0f) / (float)jiffies_total_delta);
 	}
 	*cpu_count = _cpu_count;
 
@@ -130,7 +134,7 @@ get_task_cmdline (Task *task)
 	gint i;
 	gint c;
 
-	snprintf (filename, 96, "/proc/%i/cmdline", task->pid);
+	snprintf (filename, sizeof(filename), "/proc/%i/cmdline", task->pid);
 	if ((file = fopen (filename, "r")) == NULL)
 		return FALSE;
 
@@ -156,7 +160,7 @@ get_task_cmdline (Task *task)
 }
 
 static void
-get_cpu_percent (guint pid, gulong jiffies_user, gfloat *cpu_user, gulong jiffies_system, gfloat *cpu_system)
+get_cpu_percent (GPid pid, gulong jiffies_user, gfloat *cpu_user, gulong jiffies_system, gfloat *cpu_system)
 {
 	static GHashTable *hash_cpu_user = NULL;
 	static GHashTable *hash_cpu_system = NULL;
@@ -168,37 +172,44 @@ get_cpu_percent (guint pid, gulong jiffies_user, gfloat *cpu_user, gulong jiffie
 		hash_cpu_system = g_hash_table_new (NULL, NULL);
 	}
 
-	jiffies_user_old = GPOINTER_TO_UINT (g_hash_table_lookup (hash_cpu_user, GUINT_TO_POINTER (pid)));
-	jiffies_system_old = GPOINTER_TO_UINT (g_hash_table_lookup (hash_cpu_system, GUINT_TO_POINTER (pid)));
-	g_hash_table_insert (hash_cpu_user, GUINT_TO_POINTER (pid), GUINT_TO_POINTER (jiffies_user));
-	g_hash_table_insert (hash_cpu_system, GUINT_TO_POINTER (pid), GUINT_TO_POINTER (jiffies_system));
+	jiffies_user_old = GPOINTER_TO_UINT (g_hash_table_lookup (hash_cpu_user, GINT_TO_POINTER (pid)));
+	jiffies_system_old = GPOINTER_TO_UINT (g_hash_table_lookup (hash_cpu_system, GINT_TO_POINTER (pid)));
+	g_hash_table_insert (hash_cpu_user, GINT_TO_POINTER (pid), GUINT_TO_POINTER (jiffies_user));
+	g_hash_table_insert (hash_cpu_system, GINT_TO_POINTER (pid), GUINT_TO_POINTER (jiffies_system));
 
 	if (jiffies_user < jiffies_user_old || jiffies_system < jiffies_system_old)
 		return;
 
 	if (_cpu_count > 0 && jiffies_total_delta > 0)
 	{
-		*cpu_user = (jiffies_user - jiffies_user_old) * 100 / (gdouble)jiffies_total_delta;
-		*cpu_system = (jiffies_system - jiffies_system_old) * 100 / (gdouble)jiffies_total_delta;
+		*cpu_user = (((jiffies_user - jiffies_user_old) * 100.0f) / (float)jiffies_total_delta);
+		*cpu_system = (((jiffies_system - jiffies_system_old) * 100.0f) / (float)jiffies_total_delta);
 	}
 	else
 	{
-		*cpu_user = *cpu_system = 0;
+		*cpu_user = *cpu_system = 0.0f;
 	}
 }
 
 static gboolean
-get_task_details (guint pid, Task *task)
+get_task_details (GPid pid, Task *task)
 {
 	FILE *file;
 	gchar filename[96];
 	gchar buffer[1024];
 
-	snprintf (filename, 96, "/proc/%d/stat", pid);
-	if ((file = fopen (filename, "r")) == NULL || fgets (buffer, 1024, file) == NULL)
+	snprintf (filename, sizeof(filename), "/proc/%d/stat", pid);
+	if ((file = fopen (filename, "r")) == NULL)
 		return FALSE;
+	if (fgets (buffer, sizeof(buffer), file) == NULL)
+	{
+		fclose (file);
+		return FALSE;
+	}
 	fclose (file);
 
+	memset(task, 0, sizeof(Task));
+
 	/* Scanning the short process name is unreliable with scanf when it contains
 	 * spaces, retrieve it manually and fill the buffer */
 	{
@@ -223,8 +234,6 @@ get_task_details (guint pid, Task *task)
 		gchar dummy[256];
 		gint idummy;
 		gulong jiffies_user = 0, jiffies_system = 0;
-		struct passwd *pw;
-		struct stat sstat;
 
 		sscanf(buffer, "%i %255s %1s %i %i %i %i %i %255s %255s %255s %255s %255s %lu %lu %i %i %i %d %i %i %i %llu %llu %255s %255s %255s %i %255s %255s %255s %255s %255s %255s %255s %255s %255s %255s %i %255s %255s",
 			&task->pid,	// processid
@@ -280,11 +289,22 @@ get_task_details (guint pid, Task *task)
 
 		task->rss *= get_pagesize ();
 		get_cpu_percent (task->pid, jiffies_user, &task->cpu_user, jiffies_system, &task->cpu_system);
+	}
 
-		stat (filename, &sstat);
-		pw = getpwuid (sstat.st_uid);
-		task->uid = sstat.st_uid;
-		g_strlcpy (task->uid_name, (pw != NULL) ? pw->pw_name : "nobody", sizeof (task->uid_name));
+	/* Parse the status file: it contains the UIDs */
+	{
+		guint dummy;
+
+		snprintf(filename, sizeof (filename), "/proc/%d/status", pid);
+		if ((file = fopen (filename, "r")) == NULL)
+			return FALSE;
+
+		while (fgets (buffer, sizeof(buffer), file) != NULL)
+		{
+			if (sscanf (buffer, "Uid:\t%u\t%u\t%u\t%u", &dummy, &task->uid, &dummy, &dummy) == 1) // UIDs in order: real, effective, saved set, and filesystem
+				break;
+		}
+		fclose (file);
 	}
 
 	/* Read the full command line */
@@ -299,15 +319,15 @@ get_task_list (GArray *task_list)
 {
 	GDir *dir;
 	const gchar *name;
-	guint pid;
-	Task task = { 0 };
+	GPid pid;
+	Task task;
 
 	if ((dir = g_dir_open ("/proc", 0, NULL)) == NULL)
 		return FALSE;
 
 	while ((name = g_dir_read_name(dir)) != NULL)
 	{
-		if ((pid = (guint)g_ascii_strtoull (name, NULL, 0)) > 0)
+		if ((pid = (GPid)g_ascii_strtoull (name, NULL, 0)) > 0)
 		{
 			if (get_task_details (pid, &task))
 			{
@@ -318,22 +338,24 @@ get_task_list (GArray *task_list)
 
 	g_dir_close (dir);
 
+	g_array_sort (task_list, task_pid_compare_fn);
+
 	return TRUE;
 }
 
 gboolean
-pid_is_sleeping (guint pid)
+pid_is_sleeping (GPid pid)
 {
 	FILE *file;
 	gchar filename[96];
 	gchar buffer[1024];
 	gchar state[2];
 
-	snprintf (filename, 96, "/proc/%i/status", pid);
+	snprintf (filename, sizeof(filename), "/proc/%i/status", pid);
 	if ((file = fopen (filename, "r")) == NULL)
 		return FALSE;
 
-	while (fgets (buffer, 1024, file) != NULL)
+	while (fgets (buffer, sizeof(buffer), file) != NULL)
 	{
 		if (sscanf (buffer, "State:\t%1s", state) > 0)
 			break;
@@ -342,4 +364,3 @@ pid_is_sleeping (guint pid)
 
 	return (state[0] == 'T') ? TRUE : FALSE;
 }
-
