@@ -25,9 +25,8 @@ typedef struct _Task Task;
 struct _Task
 {
 	guint		uid;
-	gchar		uid_name[256];
-	guint		pid;
-	guint		ppid;
+	GPid		pid;
+	GPid		ppid;
 	gchar		name[256];
 	gchar		cmdline[1024];
 	gchar		state[16];
@@ -45,7 +44,7 @@ struct _Task
 gboolean	get_memory_usage	(guint64 *memory_total, guint64 *memory_free, guint64 *memory_cache, guint64 *memory_buffers, guint64 *swap_total, guint64 *swap_free);
 gboolean	get_cpu_usage		(gushort *cpu_count, gfloat *cpu_user, gfloat *cpu_system);
 gboolean	get_task_list		(GArray *task_list);
-gboolean	pid_is_sleeping		(guint pid);
+gboolean	pid_is_sleeping		(GPid pid);
 
 /**
  * GObject class used to update the graphical widgets.
@@ -62,8 +61,6 @@ typedef struct _XtmTaskManager XtmTaskManager;
 
 GType			xtm_task_manager_get_type			(void);
 XtmTaskManager *	xtm_task_manager_new				(GtkTreeModel *model);
-const gchar *		xtm_task_manager_get_username			(XtmTaskManager *manager);
-const gchar *		xtm_task_manager_get_hostname			(XtmTaskManager *manager);
 void			xtm_task_manager_get_system_info		(XtmTaskManager *manager, guint *num_processes, gfloat *cpu,
 									 guint64 *memory_used, guint64 *memory_total,
 									 guint64 *swap_used, guint64 *swap_total);
@@ -92,9 +89,21 @@ enum
 	XTM_PRIORITY_VERY_HIGH,
 };
 
-void		get_owner_uid		(guint *owner_uid, gchar **owner_uid_name);
-gchar *		get_hostname		(void);
-gboolean	send_signal_to_pid	(guint pid, gint xtm_signal);
-gboolean	set_priority_to_pid	(guint pid, gint priority);
+gchar *		get_uid_name		(guint uid);
+gboolean	send_signal_to_pid	(GPid pid, gint xtm_signal);
+gint		task_pid_compare_fn	(gconstpointer a, gconstpointer b);
+gboolean	set_priority_to_pid	(GPid pid, gint priority);
+
+
+#ifndef __unused
+#	define __unused				__attribute__((__unused__))
+#endif
+
+#if DEBUG
+#	define G_DEBUG_FMT(fmt, args...)	g_debug((fmt), ##args)
+#else
+#	define G_DEBUG_FMT(fmt, args...)
+#endif
+
 
 #endif /* !TASK_MANAGER_H */
